@@ -108,26 +108,10 @@ def main():
                 host=CONF.bind_host
             )
 
-        if CONF.enforce_secure_rbac != CONF.oslo_policy.enforce_new_defaults:
-            fail_message = (
-                "[DEFAULT] enforce_secure_rbac does not match "
-                "[oslo_policy] enforce_new_defaults. Please set both to "
-                "True to enable secure RBAC personas. Otherwise, make sure "
-                "both are False.")
-            raise exception.ServerError(fail_message)
-
         # NOTE(danms): Configure system-wide threading model to use eventlet
         glance.async_.set_threadpool_model('eventlet')
 
-        # NOTE(abhishekk): Added initialize_prefetcher KW argument to Server
-        # object so that prefetcher object should only be initialized in case
-        # of API service and ignored in case of registry. Once registry is
-        # removed this parameter should be removed as well.
-        initialize_prefetcher = False
-        if CONF.paste_deploy.flavor == 'keystone+cachemanagement':
-            initialize_prefetcher = True
-        server = wsgi.Server(initialize_glance_store=True,
-                             initialize_prefetcher=initialize_prefetcher)
+        server = wsgi.Server(initialize_glance_store=True)
         server.start(config.load_paste_app('glance-api'), default_port=9292)
         server.wait()
     except Exception as e:
