@@ -18,7 +18,6 @@
 """
 A simple cache management utility for Glance.
 """
-from __future__ import print_function
 
 import argparse
 import collections
@@ -32,8 +31,6 @@ import uuid
 from oslo_utils import encodeutils
 import prettytable
 
-from six.moves import input
-
 # If ../glance/__init__.py exists, add ../ to Python search path, so that
 # it will override what happens to be installed in /usr/(local/)lib/python...
 possible_topdir = os.path.normpath(os.path.join(os.path.abspath(sys.argv[0]),
@@ -502,6 +499,9 @@ def user_confirm(prompt, default=False):
 
 
 def main():
+    print('In the Caracal development cycle, the glance-cache-manage command '
+          'has been deprecated in favor of the new Cache API. It is scheduled '
+          'to be removed in the Dalmatian development cycle.', file=sys.stderr)
     parser = argparse.ArgumentParser(
         description=_format_command_help(),
         formatter_class=argparse.RawDescriptionHelpFormatter)
