@@ -170,7 +170,7 @@ class PropertyRules(object):
                     LOG.warning(
                         _LW('Property protection on operation %(operation)s'
                             ' for rule %(rule)s is not found. No role will be'
-                            ' allowed to perform this operation.') %
+                            ' allowed to perform this operation.'),
                         {'operation': operation,
                          'rule': property_exp})
 
