@@ -258,6 +258,43 @@ class TaskInfo(BASE, models.ModelBase):
     message = Column(Text)
 
 
+class NodeReference(BASE, models.ModelBase):
+    """Represents node info in the datastore"""
+    __tablename__ = 'node_reference'
+    __table_args__ = (UniqueConstraint(
+        'node_reference_url',
+        name='uq_node_reference_node_reference_url'),)
+
+    node_reference_id = Column(BigInteger().with_variant(Integer, 'sqlite'),
+                               primary_key=True,
+                               nullable=False, autoincrement=True)
+    node_reference_url = Column(String(length=255),
+                                nullable=False)
+
+
+class CachedImages(BASE, models.ModelBase):
+    """Represents an image tag in the datastore."""
+    __tablename__ = 'cached_images'
+    __table_args__ = (UniqueConstraint(
+        'image_id',
+        'node_reference_id',
+        name='ix_cached_images_image_id_node_reference_id'),)
+
+    id = Column(BigInteger().with_variant(Integer, 'sqlite'),
+                primary_key=True, autoincrement=True,
+                nullable=False)
+    image_id = Column(String(36), nullable=False)
+    last_accessed = Column(DateTime, nullable=False)
+    last_modified = Column(DateTime, nullable=False)
+    size = Column(BigInteger(), nullable=False)
+    hits = Column(Integer, nullable=False)
+    checksum = Column(String(32), nullable=True)
+    node_reference_id = Column(
+        BigInteger().with_variant(Integer, 'sqlite'),
+        ForeignKey('node_reference.node_reference_id'),
+        nullable=False)
+
+
 def register_models(engine):
     """Create database tables for all models with the given engine."""
     models = (Image, ImageProperty, ImageMember)
