@@ -32,8 +32,8 @@ from glance.i18n import _, _LE, _LI, _LW
 LOG = logging.getLogger(__name__)
 
 image_cache_opts = [
-    cfg.StrOpt('image_cache_driver', default='sqlite',
-               choices=('sqlite', 'xattr'), ignore_case=True,
+    cfg.StrOpt('image_cache_driver', default='centralized_db',
+               choices=('centralized_db', 'sqlite', 'xattr'), ignore_case=True,
                help=_("""
 The driver to use for image cache management.
 
@@ -50,13 +50,21 @@ and prospective) must implement this interface. Currently available drivers
 are ``sqlite`` and ``xattr``. These drivers primarily differ in the way they
 store the information about cached images:
 
-* The ``sqlite`` driver uses a sqlite database (which sits on every glance
-  node locally) to track the usage of cached images.
+* The ``centralized_db`` driver uses a central database (which will be common
+  for all glance nodes) to track the usage of cached images.
+* The ``sqlite`` (deprecated) driver uses a sqlite database (which sits on
+  every glance node locally) to track the usage of cached images.
 * The ``xattr`` driver uses the extended attributes of files to store this
   information. It also requires a filesystem that sets ``atime`` on the files
   when accessed.
 
+Deprecation warning:
+    * As centralized database will now be used for image cache management, the
+      use of `sqlite` database and driver will be dropped from 'E' (2025.1)
+      development cycle.
+
 Possible values:
+    * centralized_db
     * sqlite
     * xattr
 
@@ -371,7 +379,7 @@ class ImageCache(object):
         except Exception as e:
             LOG.exception(_LE("Exception encountered while tee'ing "
                               "image '%(image_id)s' into cache: %(error)s. "
-                              "Continuing with response.") %
+                              "Continuing with response."),
                           {'image_id': image_id,
                            'error': encodeutils.exception_to_unicode(e)})
 
