@@ -99,11 +99,15 @@ class ImageRepoProxy(glance.domain.proxy.Repo):
                                              item_proxy_class=ImageProxy,
                                              item_proxy_kwargs=proxy_kwargs)
 
-    def _enforce_image_property_quota(self, attempted):
+    def _enforce_image_property_quota(self, properties):
         if CONF.image_property_quota < 0:
             # If value is negative, allow unlimited number of properties
             return
 
+        attempted = len(
+            [x for x in properties.keys()
+             if not x.startswith(glance.api.common.GLANCE_RESERVED_NS)])
+
         maximum = CONF.image_property_quota
         if attempted > maximum:
             kwargs = {'attempted': attempted, 'maximum': maximum}
@@ -113,11 +117,11 @@ class ImageRepoProxy(glance.domain.proxy.Repo):
 
     def save(self, image, from_state=None):
         if image.added_new_properties():
-            self._enforce_image_property_quota(len(image.extra_properties))
+            self._enforce_image_property_quota(image.extra_properties)
         return super(ImageRepoProxy, self).save(image, from_state=from_state)
 
     def add(self, image):
-        self._enforce_image_property_quota(len(image.extra_properties))
+        self._enforce_image_property_quota(image.extra_properties)
         return super(ImageRepoProxy, self).add(image)
 
 
@@ -306,7 +310,7 @@ class ImageProxy(glance.domain.proxy.Image):
         super(ImageProxy, self).__init__(image)
         self.orig_props = set(image.extra_properties.keys())
 
-    def set_data(self, data, size=None, backend=None):
+    def set_data(self, data, size=None, backend=None, set_active=True):
         remaining = glance.api.common.check_quota(
             self.context, size, self.db_api, image_id=self.image.image_id)
         if remaining is not None:
@@ -315,7 +319,8 @@ class ImageProxy(glance.domain.proxy.Image):
             data = utils.LimitingReader(
                 data, remaining, exception_class=exception.StorageQuotaFull)
 
-        self.image.set_data(data, size=size, backend=backend)
+        self.image.set_data(data, size=size, backend=backend,
+                            set_active=set_active)
 
         # NOTE(jbresnah) If two uploads happen at the same time and neither
         # properly sets the size attribute[1] then there is a race condition
