@@ -107,7 +107,6 @@ class BaseServer(metaclass=abc.ABCMeta):
         self.process_pid = None
         self.server_module = None
         self.stop_kill = False
-        self.send_identity_credentials = False
 
     def write_conf(self, **kwargs):
         """
@@ -181,8 +180,8 @@ class BaseServer(metaclass=abc.ABCMeta):
             conf_filepath = os.path.join(conf_dir, 'glance-manage.conf')
 
             with open(conf_filepath, 'w') as conf_file:
-                conf_file.write('[DEFAULT]\n')
-                conf_file.write('sql_connection = %s' % self.sql_connection)
+                conf_file.write('[database]\n')
+                conf_file.write('connection = %s' % self.sql_connection)
                 conf_file.flush()
 
             glance_db_env = 'GLANCE_DB_TEST_SQLITE_FILE'
@@ -420,8 +419,6 @@ class ApiServer(Server):
         self.location_strategy = 'location_order'
         self.store_type_location_strategy_preference = ""
 
-        self.send_identity_headers = False
-
         self.node_staging_uri = 'file://%s' % os.path.join(
             self.test_dir, 'staging')
 
@@ -431,16 +428,13 @@ default_log_levels = eventlet.wsgi.server=DEBUG,stevedore.extension=INFO
 bind_host = %(bind_host)s
 bind_port = %(bind_port)s
 metadata_encryption_key = %(metadata_encryption_key)s
-send_identity_credentials = %(send_identity_credentials)s
 log_file = %(log_file)s
 image_size_cap = %(image_size_cap)d
 delayed_delete = %(delayed_delete)s
 workers = %(workers)s
 scrub_time = %(scrub_time)s
-send_identity_headers = %(send_identity_headers)s
 image_cache_dir = %(image_cache_dir)s
 image_cache_driver = %(image_cache_driver)s
-sql_connection = %(sql_connection)s
 show_image_direct_url = %(show_image_direct_url)s
 show_multiple_locations = %(show_multiple_locations)s
 user_storage_quota = %(user_storage_quota)s
@@ -454,6 +448,8 @@ image_location_quota=%(image_location_quota)s
 location_strategy=%(location_strategy)s
 allow_additional_image_properties = True
 node_staging_uri=%(node_staging_uri)s
+[database]
+connection = %(sql_connection)s
 [oslo_policy]
 policy_file = %(policy_file)s
 policy_default_rule = %(policy_default_rule)s
@@ -468,23 +464,35 @@ default_store = %(default_store)s
 [import_filtering_opts]
 allowed_ports = []
 """
-        self.paste_conf_base = """[pipeline:glance-api]
+        self.paste_conf_base = """[composite:glance-api]
+paste.composite_factory = glance.api:root_app_factory
+/: api
+/healthcheck: healthcheck
+
+[pipeline:api]
 pipeline =
     cors
-    healthcheck
     versionnegotiation
     gzip
     unauthenticated-context
     rootapp
 
-[pipeline:glance-api-caching]
-pipeline = cors healthcheck versionnegotiation gzip context
- cache rootapp
+[composite:glance-api-caching]
+paste.composite_factory = glance.api:root_app_factory
+/: api-caching
+/healthcheck: healthcheck
 
-[pipeline:glance-api-cachemanagement]
+[pipeline:api-caching]
+pipeline = cors versionnegotiation gzip context cache rootapp
+
+[composite:glance-api-cachemanagement]
+paste.composite_factory = glance.api:root_app_factory
+/: api-cachemanagement
+/healthcheck: healthcheck
+
+[pipeline:api-cachemanagement]
 pipeline =
     cors
-    healthcheck
     versionnegotiation
     gzip
     unauthenticated-context
@@ -492,11 +500,21 @@ pipeline =
     cache_manage
     rootapp
 
-[pipeline:glance-api-fakeauth]
-pipeline = cors healthcheck versionnegotiation gzip fakeauth context rootapp
+[composite:glance-api-fakeauth]
+paste.composite_factory = glance.api:root_app_factory
+/: api-fakeauth
+/healthcheck: healthcheck
 
-[pipeline:glance-api-noauth]
-pipeline = cors healthcheck versionnegotiation gzip context rootapp
+[pipeline:api-fakeauth]
+pipeline = cors versionnegotiation gzip fakeauth context rootapp
+
+[composite:glance-api-noauth]
+paste.composite_factory = glance.api:root_app_factory
+/: api-noauth
+/healthcheck: healthcheck
+
+[pipeline:api-noauth]
+pipeline = cors versionnegotiation gzip context rootapp
 
 [composite:rootapp]
 paste.composite_factory = glance.api:root_app_factory
@@ -509,14 +527,13 @@ paste.app_factory = glance.api.versions:create_resource
 [app:apiv2app]
 paste.app_factory = glance.api.v2.router:API.factory
 
-[filter:healthcheck]
-paste.filter_factory = oslo_middleware:Healthcheck.factory
+[app:healthcheck]
+paste.app_factory = oslo_middleware:Healthcheck.app_factory
 backends = disable_by_file
 disable_by_file_path = %(disable_path)s
 
 [filter:versionnegotiation]
-paste.filter_factory =
- glance.api.middleware.version_negotiation:VersionNegotiationFilter.factory
+paste.filter_factory = glance.api.middleware.version_negotiation:VersionNegotiationFilter.factory
 
 [filter:gzip]
 paste.filter_factory = glance.api.middleware.gzip:GzipMiddleware.factory
@@ -525,15 +542,13 @@ paste.filter_factory = glance.api.middleware.gzip:GzipMiddleware.factory
 paste.filter_factory = glance.api.middleware.cache:CacheFilter.factory
 
 [filter:cache_manage]
-paste.filter_factory =
- glance.api.middleware.cache_manage:CacheManageFilter.factory
+paste.filter_factory = glance.api.middleware.cache_manage:CacheManageFilter.factory
 
 [filter:context]
 paste.filter_factory = glance.api.middleware.context:ContextMiddleware.factory
 
 [filter:unauthenticated-context]
-paste.filter_factory =
- glance.api.middleware.context:UnauthenticatedContextMiddleware.factory
+paste.filter_factory = glance.api.middleware.context:UnauthenticatedContextMiddleware.factory
 
 [filter:fakeauth]
 paste.filter_factory = glance.tests.utils:FakeAuthMiddleware.factory
@@ -594,24 +609,19 @@ class ApiServerForMultipleBackend(Server):
         self.location_strategy = 'location_order'
         self.store_type_location_strategy_preference = ""
 
-        self.send_identity_headers = False
-
         self.conf_base = """[DEFAULT]
 debug = %(debug)s
 default_log_levels = eventlet.wsgi.server=DEBUG,stevedore.extension=INFO
 bind_host = %(bind_host)s
 bind_port = %(bind_port)s
 metadata_encryption_key = %(metadata_encryption_key)s
-send_identity_credentials = %(send_identity_credentials)s
 log_file = %(log_file)s
 image_size_cap = %(image_size_cap)d
 delayed_delete = %(delayed_delete)s
 workers = %(workers)s
 scrub_time = %(scrub_time)s
-send_identity_headers = %(send_identity_headers)s
 image_cache_dir = %(image_cache_dir)s
 image_cache_driver = %(image_cache_driver)s
-sql_connection = %(sql_connection)s
 show_image_direct_url = %(show_image_direct_url)s
 show_multiple_locations = %(show_multiple_locations)s
 user_storage_quota = %(user_storage_quota)s
@@ -625,6 +635,8 @@ image_location_quota=%(image_location_quota)s
 location_strategy=%(location_strategy)s
 allow_additional_image_properties = True
 enabled_backends=file1:file,file2:file,file3:file
+[database]
+connection = %(sql_connection)s
 [oslo_policy]
 policy_file = %(policy_file)s
 policy_default_rule = %(policy_default_rule)s
@@ -646,23 +658,35 @@ allowed_ports = []
 [os_glance_staging_store]
 filesystem_store_datadir=%(staging_dir)s
 """
-        self.paste_conf_base = """[pipeline:glance-api]
+        self.paste_conf_base = """[composite:glance-api]
+paste.composite_factory = glance.api:root_app_factory
+/: api
+/healthcheck: healthcheck
+
+[pipeline:api]
 pipeline =
     cors
-    healthcheck
     versionnegotiation
     gzip
     unauthenticated-context
     rootapp
 
-[pipeline:glance-api-caching]
-pipeline = cors healthcheck versionnegotiation gzip unauthenticated-context
- cache rootapp
+[composite:glance-api-caching]
+paste.composite_factory = glance.api:root_app_factory
+/: api-caching
+/healthcheck: healthcheck
 
-[pipeline:glance-api-cachemanagement]
+[pipeline:api-caching]
+pipeline = cors versionnegotiation gzip unauthenticated-context cache rootapp
+
+[composite:glance-api-cachemanagement]
+paste.composite_factory = glance.api:root_app_factory
+/: api-cachemanagement
+/healthcheck: healthcheck
+
+[pipeline:api-cachemanagement]
 pipeline =
     cors
-    healthcheck
     versionnegotiation
     gzip
     unauthenticated-context
@@ -670,11 +694,21 @@ pipeline =
     cache_manage
     rootapp
 
-[pipeline:glance-api-fakeauth]
-pipeline = cors healthcheck versionnegotiation gzip fakeauth context rootapp
+[composite:glance-api-fakeauth]
+paste.composite_factory = glance.api:root_app_factory
+/: api-fakeauth
+/healthcheck: healthcheck
 
-[pipeline:glance-api-noauth]
-pipeline = cors healthcheck versionnegotiation gzip context rootapp
+[pipeline:api-fakeauth]
+pipeline = cors versionnegotiation gzip fakeauth context rootapp
+
+[composite:glance-api-noauth]
+paste.composite_factory = glance.api:root_app_factory
+/: api-noauth
+/healthcheck: healthcheck
+
+[pipeline:api-noauth]
+pipeline = cors versionnegotiation gzip context rootapp
 
 [composite:rootapp]
 paste.composite_factory = glance.api:root_app_factory
@@ -687,14 +721,13 @@ paste.app_factory = glance.api.versions:create_resource
 [app:apiv2app]
 paste.app_factory = glance.api.v2.router:API.factory
 
-[filter:healthcheck]
-paste.filter_factory = oslo_middleware:Healthcheck.factory
+[app:healthcheck]
+paste.app_factory = oslo_middleware:Healthcheck.app_factory
 backends = disable_by_file
 disable_by_file_path = %(disable_path)s
 
 [filter:versionnegotiation]
-paste.filter_factory =
- glance.api.middleware.version_negotiation:VersionNegotiationFilter.factory
+paste.filter_factory = glance.api.middleware.version_negotiation:VersionNegotiationFilter.factory
 
 [filter:gzip]
 paste.filter_factory = glance.api.middleware.gzip:GzipMiddleware.factory
@@ -703,15 +736,13 @@ paste.filter_factory = glance.api.middleware.gzip:GzipMiddleware.factory
 paste.filter_factory = glance.api.middleware.cache:CacheFilter.factory
 
 [filter:cache_manage]
-paste.filter_factory =
- glance.api.middleware.cache_manage:CacheManageFilter.factory
+paste.filter_factory = glance.api.middleware.cache_manage:CacheManageFilter.factory
 
 [filter:context]
 paste.filter_factory = glance.api.middleware.context:ContextMiddleware.factory
 
 [filter:unauthenticated-context]
-paste.filter_factory =
- glance.api.middleware.context:UnauthenticatedContextMiddleware.factory
+paste.filter_factory = glance.api.middleware.context:UnauthenticatedContextMiddleware.factory
 
 [filter:fakeauth]
 paste.filter_factory = glance.tests.utils:FakeAuthMiddleware.factory
@@ -747,8 +778,6 @@ class ScrubberDaemon(Server):
         self.policy_file = policy_file
         self.policy_default_rule = 'default'
 
-        self.send_identity_headers = False
-
         self.conf_base = """[DEFAULT]
 debug = %(debug)s
 log_file = %(log_file)s
@@ -757,8 +786,9 @@ wakeup_time = 2
 scrub_time = %(scrub_time)s
 metadata_encryption_key = %(metadata_encryption_key)s
 lock_path = %(lock_path)s
-sql_connection = %(sql_connection)s
 sql_idle_timeout = 3600
+[database]
+connection = %(sql_connection)s
 [glance_store]
 filesystem_store_datadir=%(image_dir)s
 [oslo_policy]
@@ -800,7 +830,7 @@ class FunctionalTest(test_utils.BaseTestCase):
         # The clients will try to connect to this address. Let's make sure
         # we're not using the default '0.0.0.0'
         self.config(bind_host='127.0.0.1')
-
+        self.config(image_cache_dir=self.test_dir)
         self.tracecmd = tracecmd_osmap.get(platform.system())
 
         conf_dir = os.path.join(self.test_dir, 'etc')
@@ -1600,7 +1630,7 @@ class SynchronousAPIBase(test_utils.BaseTestCase):
         self.setup_simple_paste()
         self.setup_stores()
 
-    def start_server(self, enable_cache=True):
+    def start_server(self, enable_cache=True, set_worker_url=True):
         """Builds and "starts" the API server.
 
         Note that this doesn't actually "start" anything like
@@ -1613,6 +1643,9 @@ class SynchronousAPIBase(test_utils.BaseTestCase):
             root_app = 'glance-api-cachemanagement'
             self.config(image_cache_dir=self._store_dir('cache'))
 
+        if set_worker_url:
+            self.config(worker_self_reference_url='http://workerx')
+
         self.api = config.load_paste_app(root_app,
                                          conf_file=self.paste_config)
         self.config(enforce_new_defaults=True,
