@@ -13,9 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import http.client as http
+
 from oslo_serialization import jsonutils
 import requests
-from six.moves import http_client as http
 
 from glance.tests.functional.v2 import metadef_base
 
@@ -111,7 +112,7 @@ class TestMetadefResourceTypes(metadef_base.MetadefFunctionalTestBase):
             u'properties_target',
         ])
         for key, value in expected_metadef_resource_types.items():
-            if(key in checked_values):
+            if key in checked_values:
                 self.assertEqual(
                     resource_type['resource_type_associations'][0][key],
                     value, key)
