@@ -16,10 +16,12 @@
 import http.client
 from unittest import mock
 
+from oslo_log.fixture import logging_error as log_fixture
 import testtools
 
 from glance.common import auth
 from glance.common import client
+from glance.tests.unit import fixtures as glance_fixtures
 from glance.tests import utils
 
 
@@ -29,10 +31,14 @@ class TestClient(testtools.TestCase):
         super(TestClient, self).setUp()
         self.endpoint = 'example.com'
         self.client = client.BaseClient(self.endpoint, port=9191,
-                                        auth_token=u'abc123')
+                                        auth_token='abc123')
 
-    def tearDown(self):
-        super(TestClient, self).tearDown()
+        # Limit the amount of DeprecationWarning messages in the unit test logs
+        self.useFixture(glance_fixtures.WarningsFixture())
+
+        # Make sure logging output is limited but still test debug formatting
+        self.useFixture(log_fixture.get_logging_handle_error_fixture())
+        self.useFixture(glance_fixtures.StandardLogging())
 
     def test_make_auth_plugin(self):
         creds = {'strategy': 'keystone'}
@@ -49,7 +55,7 @@ class TestClient(testtools.TestCase):
         fake = utils.FakeHTTPResponse(data=b"Ok")
         _mock_resp.return_value = fake
 
-        headers = {"test": u'ni\xf1o'}
+        headers = {"test": 'ni\xf1o'}
         resp = self.client.do_request('GET', '/v1/images/detail',
                                       headers=headers)
         self.assertEqual(fake, resp)
@@ -62,7 +68,7 @@ class TestClient(testtools.TestCase):
         fake = utils.FakeHTTPResponse(data=b"Ok")
         _mock_resp.return_value = fake
 
-        params = {"test": u'ni\xf1o'}
+        params = {"test": 'ni\xf1o'}
         resp = self.client.do_request('GET', '/v1/images/detail',
                                       params=params)
         self.assertEqual(fake, resp)
