@@ -12,7 +12,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from __future__ import absolute_import
+import collections
+import http.client as http
+import io
 from unittest import mock
 
 import copy
@@ -22,9 +24,6 @@ import uuid
 
 import fixtures
 from oslo_serialization import jsonutils
-import six
-from six import moves
-from six.moves import http_client as http
 import webob
 
 from glance.cmd import replicator as glance_replicator
@@ -112,7 +111,7 @@ class FakeHTTPConnection(object):
         class FakeResponse(object):
             def __init__(self, args):
                 (code, body, headers) = args
-                self.body = six.StringIO(body)
+                self.body = io.StringIO(body)
                 self.headers = headers
                 self.status = code
 
@@ -248,7 +247,7 @@ class ImageServiceTestCase(test_utils.BaseTestCase):
 class FakeHttpResponse(object):
     def __init__(self, headers, data):
         self.headers = headers
-        self.data = six.BytesIO(data)
+        self.data = io.BytesIO(data)
 
     def getheaders(self):
         return self.headers
@@ -307,7 +306,7 @@ def get_image_service():
 
 
 def check_no_args(command, args):
-    options = moves.UserDict()
+    options = collections.UserDict()
     no_args_error = False
 
     orig_img_service = glance_replicator.get_image_service
@@ -324,7 +323,7 @@ def check_no_args(command, args):
 
 
 def check_bad_args(command, args):
-    options = moves.UserDict()
+    options = collections.UserDict()
     bad_args_error = False
 
     orig_img_service = glance_replicator.get_image_service
@@ -352,13 +351,13 @@ class ReplicationCommandsTestCase(test_utils.BaseTestCase):
         self.assertEqual(2, mock_lookup_command.call_count)
 
     def test_replication_size(self):
-        options = moves.UserDict()
+        options = collections.UserDict()
         options.targettoken = 'targettoken'
         args = ['localhost:9292']
 
         stdout = sys.stdout
         orig_img_service = glance_replicator.get_image_service
-        sys.stdout = six.StringIO()
+        sys.stdout = io.StringIO()
         try:
             glance_replicator.get_image_service = get_image_service
             glance_replicator.replication_size(options, args)
@@ -406,7 +405,7 @@ class ReplicationCommandsTestCase(test_utils.BaseTestCase):
     def test_replication_dump(self):
         tempdir = self.useFixture(fixtures.TempDir()).path
 
-        options = moves.UserDict()
+        options = collections.UserDict()
         options.chunksize = 4096
         options.sourcetoken = 'sourcetoken'
         options.metaonly = False
@@ -493,7 +492,7 @@ class ReplicationCommandsTestCase(test_utils.BaseTestCase):
             f.write(jsonutils.dumps([1, 2, 3, 4, 5]))
 
         # Finally, we're ready to test
-        options = moves.UserDict()
+        options = collections.UserDict()
         options.dontreplicate = 'dontrepl dontreplabsent'
         options.targettoken = 'targettoken'
         args = ['localhost:9292', tempdir]
@@ -521,7 +520,7 @@ class ReplicationCommandsTestCase(test_utils.BaseTestCase):
         self.assertTrue(check_bad_args(command, args))
 
     def test_replication_livecopy(self):
-        options = moves.UserDict()
+        options = collections.UserDict()
         options.chunksize = 4096
         options.dontreplicate = 'dontrepl dontreplabsent'
         options.sourcetoken = 'livesourcetoken'
@@ -549,7 +548,7 @@ class ReplicationCommandsTestCase(test_utils.BaseTestCase):
         self.assertTrue(check_bad_args(command, args))
 
     def test_replication_compare(self):
-        options = moves.UserDict()
+        options = collections.UserDict()
         options.chunksize = 4096
         options.dontreplicate = 'dontrepl dontreplabsent'
         options.sourcetoken = 'livesourcetoken'
