@@ -15,9 +15,9 @@
 #    under the License.
 
 import datetime
+from unittest import mock
 
 import glance_store
-import mock
 from oslo_config import cfg
 import oslo_messaging
 import webob
@@ -44,7 +44,7 @@ class ImageStub(glance.domain.Image):
     def get_data(self, offset=0, chunk_size=None):
         return ['01234', '56789']
 
-    def set_data(self, data, size, backend=None):
+    def set_data(self, data, size, backend=None, set_active=True):
         for chunk in data:
             pass
 
@@ -272,10 +272,17 @@ class TestImageNotifications(utils.BaseTestCase):
             self.assertEqual('INFO', output_log['notification_type'])
             self.assertEqual('image.prepare', output_log['event_type'])
             self.assertEqual(self.image.image_id, output_log['payload']['id'])
+            self.assertEqual(['store1', 'store2'], output_log['payload'][
+                'os_glance_importing_to_stores'])
+            self.assertEqual([],
+                             output_log['payload']['os_glance_failed_import'])
             yield 'abcd'
             yield 'efgh'
             insurance['called'] = True
 
+        self.image_proxy.extra_properties[
+            'os_glance_importing_to_stores'] = 'store1,store2'
+        self.image_proxy.extra_properties['os_glance_failed_import'] = ''
         self.image_proxy.set_data(data_iterator(), 8)
         self.assertTrue(insurance['called'])
 
@@ -294,39 +301,83 @@ class TestImageNotifications(utils.BaseTestCase):
         self.assertTrue(insurance['called'])
 
     def test_image_set_data_upload_and_activate_notification(self):
+        image = ImageStub(image_id=UUID1, name='image-1', status='queued',
+                          created_at=DATETIME, updated_at=DATETIME,
+                          owner=TENANT1, visibility='public')
+        context = glance.context.RequestContext(tenant=TENANT2, user=USER1)
+        fake_notifier = unit_test_utils.FakeNotifier()
+        image_proxy = glance.notifier.ImageProxy(image, context, fake_notifier)
+
         def data_iterator():
-            self.notifier.log = []
+            fake_notifier.log = []
             yield 'abcde'
             yield 'fghij'
+            image_proxy.extra_properties[
+                'os_glance_importing_to_stores'] = 'store2'
 
-        self.image_proxy.set_data(data_iterator(), 10)
+        image_proxy.extra_properties[
+            'os_glance_importing_to_stores'] = 'store1,store2'
+        image_proxy.extra_properties['os_glance_failed_import'] = ''
+        image_proxy.set_data(data_iterator(), 10)
 
-        output_logs = self.notifier.get_logs()
+        output_logs = fake_notifier.get_logs()
         self.assertEqual(2, len(output_logs))
 
         output_log = output_logs[0]
         self.assertEqual('INFO', output_log['notification_type'])
         self.assertEqual('image.upload', output_log['event_type'])
         self.assertEqual(self.image.image_id, output_log['payload']['id'])
+        self.assertEqual(['store2'], output_log['payload'][
+            'os_glance_importing_to_stores'])
+        self.assertEqual([],
+                         output_log['payload']['os_glance_failed_import'])
 
         output_log = output_logs[1]
         self.assertEqual('INFO', output_log['notification_type'])
         self.assertEqual('image.activate', output_log['event_type'])
         self.assertEqual(self.image.image_id, output_log['payload']['id'])
 
-    def test_image_set_data_upload_and_activate_notification_disabled(self):
+    def test_image_set_data_upload_and_not_activate_notification(self):
         insurance = {'called': False}
 
         def data_iterator():
             self.notifier.log = []
             yield 'abcde'
             yield 'fghij'
+            self.image_proxy.extra_properties[
+                'os_glance_importing_to_stores'] = 'store2'
+            insurance['called'] = True
+
+        self.image_proxy.set_data(data_iterator(), 10)
+
+        output_logs = self.notifier.get_logs()
+        self.assertEqual(1, len(output_logs))
+
+        output_log = output_logs[0]
+        self.assertEqual('INFO', output_log['notification_type'])
+        self.assertEqual('image.upload', output_log['event_type'])
+        self.assertEqual(self.image.image_id, output_log['payload']['id'])
+        self.assertTrue(insurance['called'])
+
+    def test_image_set_data_upload_and_activate_notification_disabled(self):
+        insurance = {'called': False}
+        image = ImageStub(image_id=UUID1, name='image-1', status='queued',
+                          created_at=DATETIME, updated_at=DATETIME,
+                          owner=TENANT1, visibility='public')
+        context = glance.context.RequestContext(tenant=TENANT2, user=USER1)
+        fake_notifier = unit_test_utils.FakeNotifier()
+        image_proxy = glance.notifier.ImageProxy(image, context, fake_notifier)
+
+        def data_iterator():
+            fake_notifier.log = []
+            yield 'abcde'
+            yield 'fghij'
             insurance['called'] = True
 
         self.config(disabled_notifications=['image.activate', 'image.upload'])
-        self.image_proxy.set_data(data_iterator(), 10)
+        image_proxy.set_data(data_iterator(), 10)
         self.assertTrue(insurance['called'])
-        output_logs = self.notifier.get_logs()
+        output_logs = fake_notifier.get_logs()
         self.assertEqual(0, len(output_logs))
 
     def test_image_set_data_storage_full(self):
@@ -582,6 +633,9 @@ class TestTaskNotifications(utils.BaseTestCase):
             expires_at=None,
             created_at=DATETIME,
             updated_at=DATETIME,
+            image_id='fake_image_id',
+            user_id='fake_user',
+            request_id='fake_request_id',
         )
 
         self.task = Task(
@@ -594,7 +648,10 @@ class TestTaskNotifications(utils.BaseTestCase):
             updated_at=DATETIME,
             task_input=task_input,
             result='res',
-            message='blah'
+            message='blah',
+            image_id='fake_image_id',
+            user_id='fake_user',
+            request_id='fake_request_id',
         )
         self.context = glance.context.RequestContext(
             tenant=TENANT2,
@@ -643,6 +700,11 @@ class TestTaskNotifications(utils.BaseTestCase):
         )
         if 'location' in output_log['payload']:
             self.fail('Notification contained location field.')
+        # Verify newly added fields 'image_id', 'user_id' and
+        # 'request_id' are not part of notification yet
+        self.assertNotIn('image_id', output_log['payload'])
+        self.assertNotIn('user_id', output_log['payload'])
+        self.assertNotIn('request_id', output_log['payload'])
 
     def test_task_create_notification_disabled(self):
         self.config(disabled_notifications=['task.create'])
@@ -673,6 +735,11 @@ class TestTaskNotifications(utils.BaseTestCase):
         )
         if 'location' in output_log['payload']:
             self.fail('Notification contained location field.')
+        # Verify newly added fields 'image_id', 'user_id' and
+        # 'request_id' are not part of notification yet
+        self.assertNotIn('image_id', output_log['payload'])
+        self.assertNotIn('user_id', output_log['payload'])
+        self.assertNotIn('request_id', output_log['payload'])
 
     def test_task_delete_notification_disabled(self):
         self.config(disabled_notifications=['task.delete'])
@@ -691,6 +758,9 @@ class TestTaskNotifications(utils.BaseTestCase):
         self.assertEqual('INFO', output_log['notification_type'])
         self.assertEqual('task.run', output_log['event_type'])
         self.assertEqual(self.task.task_id, output_log['payload']['id'])
+        self.assertNotIn(self.task.image_id, output_log['payload'])
+        self.assertNotIn(self.task.user_id, output_log['payload'])
+        self.assertNotIn(self.task.request_id, output_log['payload'])
 
     def test_task_run_notification_disabled(self):
         self.config(disabled_notifications=['task.run'])
@@ -709,6 +779,11 @@ class TestTaskNotifications(utils.BaseTestCase):
         self.assertEqual('INFO', output_log['notification_type'])
         self.assertEqual('task.processing', output_log['event_type'])
         self.assertEqual(self.task.task_id, output_log['payload']['id'])
+        # Verify newly added fields 'image_id', 'user_id' and
+        # 'request_id' are not part of notification yet
+        self.assertNotIn('image_id', output_log['payload'])
+        self.assertNotIn('user_id', output_log['payload'])
+        self.assertNotIn('request_id', output_log['payload'])
 
     def test_task_processing_notification_disabled(self):
         self.config(disabled_notifications=['task.processing'])
@@ -725,6 +800,11 @@ class TestTaskNotifications(utils.BaseTestCase):
         self.assertEqual('INFO', output_log['notification_type'])
         self.assertEqual('task.success', output_log['event_type'])
         self.assertEqual(self.task.task_id, output_log['payload']['id'])
+        # Verify newly added fields 'image_id', 'user_id' and
+        # 'request_id' are not part of notification yet
+        self.assertNotIn('image_id', output_log['payload'])
+        self.assertNotIn('user_id', output_log['payload'])
+        self.assertNotIn('request_id', output_log['payload'])
 
     def test_task_success_notification_disabled(self):
         self.config(disabled_notifications=['task.processing', 'task.success'])
@@ -741,6 +821,11 @@ class TestTaskNotifications(utils.BaseTestCase):
         self.assertEqual('INFO', output_log['notification_type'])
         self.assertEqual('task.failure', output_log['event_type'])
         self.assertEqual(self.task.task_id, output_log['payload']['id'])
+        # Verify newly added fields 'image_id', 'user_id' and
+        # 'request_id' are not part of notification yet
+        self.assertNotIn('image_id', output_log['payload'])
+        self.assertNotIn('user_id', output_log['payload'])
+        self.assertNotIn('request_id', output_log['payload'])
 
     def test_task_failure_notification_disabled(self):
         self.config(disabled_notifications=['task.failure'])
